%if 0%{?fedora} || 0%{?rhel} >= 8
%global with_py3 1
%endif

%global pkgname ZEO

Name:           python-%{pkgname}
Version:        4.1.0
Release:        1%{?dist}
Summary:        Client-server storage implementation for ZODB

License:        ZPLv2.1
URL:            http://www.zodb.org/
Source0:        https://pypi.python.org/packages/source/Z/%{pkgname}/%{pkgname}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  python-devel
BuildRequires:  python-manuel
BuildRequires:  python-persistent
BuildRequires:  python-random2
BuildRequires:  python-setuptools
BuildRequires:  python-six
BuildRequires:  python-transaction
BuildRequires:  python-zc-lockfile
BuildRequires:  python-ZConfig
BuildRequires:  python-zdaemon
BuildRequires:  python-ZODB
BuildRequires:  python-zope-interface
BuildRequires:  python-zope-testing

%if 0%{?with_py3}
BuildRequires:  python3-devel
BuildRequires:  python3-manuel
BuildRequires:  python3-persistent
BuildRequires:  python3-random2
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildRequires:  python3-transaction
BuildRequires:  python3-zc-lockfile
BuildRequires:  python3-ZConfig
BuildRequires:  python3-zdaemon
BuildRequires:  python3-ZODB
BuildRequires:  python3-zope-interface
BuildRequires:  python3-zope-testing
%endif

Requires:       python-persistent
Requires:       python-setuptools
Requires:       python-six
Requires:       python-transaction
Requires:       python-zc-lockfile
Requires:       python-ZConfig
Requires:       python-zdaemon
Requires:       python-ZODB
Requires:       python-zope-interface

%global common_desc                                                   \
ZEO is a client-server system for sharing a single storage among many \
clients.  When you use ZEO, the storage is opened in the ZEO server   \
process.  Client programs connect to this process using a ZEO         \
ClientStorage.  ZEO provides a consistent view of the database to all \
clients.  The ZEO client and server communicate using a custom RPC    \
protocol layered on top of TCP.

%description
%{common_desc}

%if 0%{?with_py3}
%package -n python3-%{pkgname}
Summary:        Client-server storage implementation for ZODB
Requires:       python3-persistent
Requires:       python3-setuptools
Requires:       python3-six
Requires:       python3-transaction
Requires:       python3-zc-lockfile
Requires:       python3-ZConfig
Requires:       python3-zdaemon
Requires:       python3-ZODB
Requires:       python3-zope-interface

%description -n python3-%{pkgname}
%{common_desc}
%endif

%prep
%setup -q -c

# Remove prebuilt egg
rm -fr %{pkgname}-%{version}/src/%{pkgname}.egg-info

# Remove backup files
find %{pkgname}-%{version}/src -name \*~ | xargs rm -f

%if 0%{?with_py3}
# Prepare for a python3 build
cp -a %{pkgname}-%{version} python3-%{pkgname}-%{version}
%endif

%build
# Python 2 build
pushd %{pkgname}-%{version}
%{__python2} setup.py build
popd

%if 0%{?with_py3}
# Python 3 build
pushd python3-%{pkgname}-%{version}
%{__python3} setup.py build
popd
%endif

%install
%if 0%{?with_py3}
# Python 3 install
pushd python3-%{pkgname}-%{version}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}
popd
for bin in runzeo zeo-nagios zeoctl zeopack zeopasswd; do
  mv %{buildroot}%{_bindir}/$bin %{buildroot}%{_bindir}/python3-${bin}
done

# Fix scripts
for script in $(grep -Rl '^#!' %{buildroot}%{python3_sitelib}/%{pkgname}); do
  sed 's,%{_bindir}/env python.*,%{_bindir}/python3,' $script > $script.new
  touch -r $script $script.new
  mv -f $script.new $script
  chmod 0755 $script
done
%endif

# Python 2 install
pushd %{pkgname}-%{version}
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}
popd

# Fix scripts
for script in $(grep -Rl '^#!' %{buildroot}%{python2_sitelib}/%{pkgname}); do
  sed 's,%{_bindir}/env python.*,%{_bindir}/python2,' $script > $script.new
  touch -r $script $script.new
  mv -f $script.new $script
  chmod 0755 $script
done

%check
# Python 2 tests
pushd %{pkgname}-%{version}
%{__python2} setup.py test
popd

%if 0%{?with_py3}
# Python 3 tests
pushd python3-%{pkgname}-%{version}
%{__python3} setup.py test
popd
%endif

%files
%doc %{pkgname}-%{version}/CHANGES.rst %{pkgname}-%{version}/README.rst
%doc %{pkgname}-%{version}/monitor.txt
%license %{pkgname}-%{version}/COPYRIGHT.txt %{pkgname}-%{version}/LICENSE.txt
%{_bindir}/runzeo
%{_bindir}/zeo-nagios
%{_bindir}/zeoctl
%{_bindir}/zeopack
%{_bindir}/zeopasswd
%{python2_sitelib}/%{pkgname}*

%if 0%{?with_py3}
%files -n python3-%{pkgname}
%doc %{pkgname}-%{version}/CHANGES.rst %{pkgname}-%{version}/README.rst
%doc %{pkgname}-%{version}/monitor.txt
%license %{pkgname}-%{version}/COPYRIGHT.txt %{pkgname}-%{version}/LICENSE.txt
%{_bindir}/python3-runzeo
%{_bindir}/python3-zeo-nagios
%{_bindir}/python3-zeoctl
%{_bindir}/python3-zeopack
%{_bindir}/python3-zeopasswd
%{python3_sitelib}/%{pkgname}*
%endif

%changelog
* Mon Jan 12 2015 Jerry James <loganjerry@gmail.com> - 4.1.0-1
- New upstream release
- Name python 3 binaries according to policy
- Use license macro

* Thu Jun 12 2014 Jerry James <loganjerry@gmail.com> - 4.0.0-1
- Initial RPM
